import React, { useEffect, useMemo } from "react";
import { Input } from "antd";
import { Node } from "@antv/x6";
import { useSafeState } from "ahooks";
export default function CustomInput(props: {
  value: string;
  styles: React.CSSProperties & {
    textVAlign: 'top' | 'middle' | 'bottom';
    bold: boolean;
    italic: boolean;
  };
  node: Node;
}) {
  const { value, styles, node } = props;
  const [isEditing, setIsEditing] = useSafeState(true);
  
  const style = useMemo(() => {
    const top = styles.textVAlign === 'top' ? 0 : styles.textVAlign === 'middle' ? '50%' : undefined;
    const bottom = styles.textVAlign === 'bottom' ? 0 : undefined;
    return {
      ...styles,
      fontWeight: styles.bold ? 'bold' : undefined,
      fontStyle: styles.italic ? 'italic' : undefined,
      transform: styles.textVAlign === 'middle' ? 'translateY(-50%)' : undefined,
      minHeight: 0,
      top,
      bottom,
    }
  }, [styles])

  // useEffect(() => {
  //   // 处理字体加载
  //   // @ts-ignore
  //   // WebFont.load({
  //   //   google: {
  //   //     families: [styles.fontFamily]
  //   //   }
  //   // })
  // }, [styles.fontFamily]);

  return (
    <div className="absolute w-full h-full w-full">
      {isEditing ? (
        <Input.TextArea
          value={value}
          variant="borderless"
          className="absolute"
          style={style}
          onChange={(e) => node.setData({ label: e.target.value })}
          onBlur={() => setIsEditing(false)}
          autoSize
          autoFocus
        />
     ) : (
        <div
          className="absolute w-full"
          style={style}
          onDoubleClick={() => setIsEditing(true)}
        >
          {value}
        </div>
      )}
    </div>
  );
}
