import { DownloadOutlined, LeftOutlined } from "@ant-design/icons";
import { Button, Input, Dropdown, MenuProps, Tooltip } from "antd";
import React, { useState } from "react";
import logo from "@/assets/logo.png";
import { Icon } from "umi";

const menuData: {
  key: string;
  label: string;
  type: "group";
  children: MenuProps["items"];
}[] = [
  {
    key: "1",
    label: "文件",
    type: "group",
    children: [
      {
        key: "1-1",
        label: "新建",
        children: [
          {
            key: "1-1-1",
            label: "流程图",
            icon: <Icon icon="local:flow"/>,
          },
          {
            key: "1-1-2",
            label: "思维导图",
            icon: <Icon icon="local:mind"/>,
          },
          {
            key: "1-1-3",

            label: "UML",
            icon: <Icon icon="local:uml"/>,
          },
          {
            key: "1-1-4",

            label: "网络拓扑图",
            icon: <Icon icon="local:net"/>,
          },
          {
            key: "1-1-5",

            label: "组织结构图",
            icon: <Icon icon="local:flow"/>,
          },
          {
            key: "1-1-6",
            label: "BPMN",
            icon: <Icon icon="local:bpmn"/>,
          },
        ],
      },
      {
        key: "1-2",
        label: "重命名",
      },
      {
        key: "1-3",
        label: "预览",
      },
      {
        key: "1-4",
        label: (
          <div className="flex justify-between">
            <span>保存</span>
            <span>Ctrl+S</span>
          </div>
        ),
      },
      {
        key: "1-5",
        label: "克隆",
      },
      {
        key: "1-6",
        type: "divider",
      },
      {
        key: "1-7",
        label: "导出为",
        children: [
          {
            key: "1-7-1",

            label: "JPG",
          },
          {
            key: "1-7-2",

            label: "PNG",
          },
        ],
      },
      {
        key: "1-8",
        type: "divider",
      },
      {
        key: "1-9",
        label: "历史记录",
      },
      {
        key: "1-0",
        label: (
          <div className="flex justify-between">
            <span>打印</span>
            <span>Ctrl+P</span>
          </div>
        ),
      },
      {
        key: "1-11",
        label: "关闭",
      },
    ],
  },
  {
    key: "2",
    type: "group",
    label: "编辑",
    children: [
      {
        key: "2-0",
        label: (
          <div className="flex justify-between">
            <span>撤销</span>
            <span>Ctrl+Z</span>
          </div>
        ),
      },
      {
        key: "2-1",
        label: (
          <div className="flex justify-between">
            <span>恢复</span>
            <span>Ctrl+Y</span>
          </div>
        ),
      },
      {
        key: "2-2",
        type: "divider",
      },
      {
        key: "2-3",
        label: (
          <div className="flex justify-between">
            <span>剪切</span>
            <span>Ctrl+X</span>
          </div>
        ),
      },
      {
        key: "2-4",
        label: (
          <div className="flex justify-between">
            <span>复制</span>
            <span>Ctrl+C</span>
          </div>
        ),
      },
      {
        key: "2-5",
        label: (
          <div className="flex justify-between">
            <span>粘贴</span>
            <span>Ctrl+V</span>
          </div>
        ),
      },
      {
        key: "2-6",
        label: (
          <div className="flex justify-between">
            <span>格式刷</span>
            <span>Ctrl+Shift+C</span>
          </div>
        ),
      },
      {
        key: "2-7",
        label: "默认样式",
      },
      {
        key: "2-8",
        type: "divider",
      },
      {
        key: "2-9",
        label: (
          <div className="flex justify-between">
            <span>查找</span>
            <span>Ctrl+F</span>
          </div>
        ),
      },
      {
        key: "2-10",
        label: (
          <div className="flex justify-between">
            <span>替换</span>
            <span>Ctrl+H</span>
          </div>
        ),
      },
      {
        key: "2-11",
        type: "divider",
      },
      {
        key: "2-12",
        label: (
          <div className="flex justify-between">
            <span>删除</span>
            <span>Delete/Backspace</span>
          </div>
        ),
      },
    ],
  },
  {
    key: "3",
    type: "group",
    label: "选择",
    children: [
      {
        key: "3-1",
        label: (
          <div className="flex justify-between">
            <span>全选</span>
            <span>Ctrl+A</span>
          </div>
        ),
      },
      {
        key: "3-2",
        type: "divider",
      },
      {
        key: "3-3",
        label: "框选部分选中数据",
      },
      {
        key: "3-4",
        label: "框选全部选中图形",
      },
    ],
  },
  {
    key: "4",
    type: "group",
    label: "视图",
    children: [
      {
        key: "4-1",
        label: (
          <div className="flex justify-between">
            <span>放大</span>
            <span>Ctrl+(+)</span>
          </div>
        ),
      },
      {
        key: "4-2",
        label: (
          <div className="flex justify-between">
            <span>缩小</span>
            <span>Ctrl+(+)</span>
          </div>
        ),
      },
      {
        key: "4-3",
        type: "divider",
      },
      {
        key: "4-4",
        label: "50%",
      },
      {
        key: "4-5",
        label: "75%",
      },
      {
        key: "4-6",
        label: "100%",
      },
      {
        key: "4-7",
        label: "150%",
      },
      {
        key: "4-8",
        label: "200%",
      },
      {
        key: "4-9",
        type: "divider",
      },
      {
        key: "4-10",
        label: (
          <div className="flex justify-between">
            <span>重置视图</span>
            <span>Ctrl+0</span>
          </div>
        ),
      },
    ],
  },
  {
    key: "5",
    type: "group",
    label: "插入",
    children: [
      {
        key: "5-1",
        label: (
          <div className="flex justify-between">
            <span>文本</span>
            <span>T</span>
          </div>
        ),
      },
      {
        key: "5-2",
        label: (
          <div className="flex justify-between">
            <span>图片</span>
            <span>I</span>
          </div>
        ),
      },
      {
        key: "5-3",
        label: "代码块",
      },
      {
        key: "5-4",
        label: (
          <div className="flex justify-between">
            <span>连线</span>
            <span>L</span>
          </div>
        ),
      },
      {
        key: "5-5",
        type: "divider",
      },
      {
        key: "5-6",
        label: "数据属性",
      },
      {
        key: "5-7",
        label: (
          <div className="flex justify-between">
            <span>评论</span>
            <span>Alt+Ctrl+M</span>
          </div>
        ),
      },
    ],
  },
  {
    key: "6",
    type: "group",
    label: "画布",
    children: [
      {
        key: "6-1",
        label: "画布大小",
      },
      {
        key: "6-2",
        label: "背景颜色",
      },
      {
        key: "6-3",
        label: "显示网格",
      },
      {
        key: "6-4",
        label: "网格大小",
        children: [
          {
            key: "6-4-1",

            label: "小",
          },
          {
            key: "6-4-2",

            label: "正常",
          },
          {
            key: "6-4-3",

            label: "大",
          },
          {
            key: "6-4-4",

            label: "很大",
          },
          {
            key: "6-4-5",

            label: "自定义",
          },
        ],
      },
      {
        key: "6-5",
        type: "divider",
      },
      {
        key: "6-6",
        label: "显示跨线",
      },
      {
        key: "6-7",
        label: "显示打印分割线",
      },
      {
        key: "6-8",
        label: "水印设置",
      },
      {
        key: "6-9",
        label: "风格设置",
      },
    ],
  },
  {
    key: "7",
    type: "group",
    label: "排列",
    children: [
      {
        key: "7-1",
        label: "置于顶层",
      },
      {
        key: "7-2",
        label: "置于底层",
      },
      {
        key: "7-3",
        label: "上移一层",
      },
      {
        key: "7-4",
        label: "下移一层",
      },
      {
        key: "7-5",
        type: "divider",
      },
      {
        key: "7-6",
        label: "分布对齐",
        children: [
          {
            key: "7-6-1",
            label: (
              <div className="flex justify-between">
                <span>左对齐</span>
                <span>Alt+L</span>
              </div>
            ),
          },
          {
            key: "7-6-2",
            label: (
              <div className="flex justify-between">
                <span>居中对齐</span>
                <span>Alt+C</span>
              </div>
            ),
          },
          {
            key: "7-6-3",
            label: (
              <div className="flex justify-between">
                <span>右对齐</span>
                <span>Alt+R</span>
              </div>
            ),
          },
          {
            key: "7-6-4",
            type: "divider",
          },
          {
            key: "7-6-5",
            label: (
              <div className="flex justify-between">
                <span>顶端对齐</span>
                <span>Alt+T</span>
              </div>
            ),
          },
          {
            key: "7-6-6",
            label: (
              <div className="flex justify-between">
                <span>垂直居中对齐</span>
                <span>Alt+M</span>
              </div>
            ),
          },
          {
            key: "7-6-8",
            label: (
              <div className="flex justify-between">
                <span>底端对齐</span>
                <span>Alt+B</span>
              </div>
            ),
          },
          {
            key: "7-6-9",
            type: "divider",
          },
          {
            key: "7-6-10",
            label: (
              <div className="flex justify-between">
                <span>水平平均分布</span>
                <span>Alt+H</span>
              </div>
            ),
          },
          {
            key: "7-6-11",
            label: (
              <div className="flex justify-between">
                <span>垂直平均分布</span>
                <span>Alt+V</span>
              </div>
            ),
          },
        ],
      },
      {
        key: "7-7",
        label: "匹配大小",
        children: [
          {
            key: "7-7-1",

            label: "宽度",
          },
          {
            key: "7-7-2",

            label: "高度",
          },
          {
            key: "7-7-3",

            label: "宽高匹配",
          },
        ],
      },
      {
        key: "7-8",
        type: "divider",
      },
      {
        key: "7-9",
        label: (
          <div className="flex justify-between">
            <span>组合</span>
            <span>Alt+G</span>
          </div>
        ),
      },
      {
        key: "7-10",
        label: (
          <div className="flex justify-between">
            <span>取消组合</span>
            <span>Alt+Shift+G</span>
          </div>
        ),
      },
      {
        key: "7-11",
        type: "divider",
      },
      {
        key: "7-12",
        label: "锁定",
      },
      {
        key: "7-13",
        label: "取消锁定",
      },
    ],
  },
];
export default function MenuBar() {
  const [name, setName] = useState("新建流程图");
  return (
    <div className="w-full px-8px flex justify-between items-center">
      <div className="menu-left flex items-center">
        <Button type="text" icon={<LeftOutlined />}></Button>
        <div className="w-40px h-40px mx-8px">
          <img className="w-40px" src={logo} />
        </div>
        <div className="flex flex-col leading-32px">
          <div>
            <Input className="text-16px" value={name} variant="borderless" />
          </div>
          <div>
            {menuData.map((item) => {
              return (
                <Dropdown
                  key={item.key}
                  menu={{ items: item.children, style: { width: 200} }}
                  placement="bottomLeft"
                >
                  <Button type="text" size="small">{item.label}</Button>
                </Dropdown>
              );
            })}
          </div>
        </div>
      </div>
      <div>
        <Dropdown menu={{ items: []}}>
          <Tooltip title='导出为'>
            <Button type="text" icon={<DownloadOutlined />}></Button>
          </Tooltip>
        </Dropdown>
      </div>
    </div>
  );
}
