import type { Cell } from "@antv/x6";

/**
 * 对齐操作
 * @param type 对齐类型
 * @param cells 元素列表
 */
export const alignCell = (type: string, cells: Cell[]) => {
  const nodes = cells?.filter((item) => item.isNode());
  if (!nodes?.length) return;

  const maxX = Math.max(...nodes.map((cell) => cell.position().x));
  const maxY = Math.max(...nodes.map((cell) => cell.position().y));
  const minX = Math.min(...nodes.map((cell) => cell.position().x));
  const minY = Math.min(...nodes.map((cell) => cell.position().y));
  const middleX = (minX + maxX) / 2;
  const middleY = (minY + maxY) / 2;
  nodes?.forEach((node, index) => {
    const { x, y } = node.position();
    switch (type) {
      case "left":
        node.setPosition(minX, y);
        break;
      case "hcenter":
        node.setPosition(x, middleY);
        break;
      case "right":
        node.setPosition(maxX, y);
        break;
      case "top":
        node.setPosition(x, minY);
        break;
      case "vcenter":
        node.setPosition(middleX, y);
        break;
      case "bottom":
        node.setPosition(x, maxY);
        break;
      case "h": {
        if (nodes.length < 3) break;
        const interval = (maxX - minX) / (nodes.length - 1);
        node.setPosition(minX + interval * index, y);
        break;
      }
      case "v": {
        if (nodes.length < 3) break;
        const interval = (maxY - minY) / (nodes.length - 1);
        node.setPosition(x, minY + interval * index);
        break;
      }
    }
  });
};

/**
 * 匹配宽高操作
 * @param type 匹配类型
 * @param cells 元素列表
 */
export const matchSize = (type: "width" | "height" | "auto", cells: Cell[]) => {
  const nodes = cells?.filter((item) => item.isNode());
  const maxWidth = nodes?.reduce((pre, cur) => {
    return Math.max(pre, cur.size().width);
  }, 0);
  const maxHeight = nodes?.reduce((pre, cur) => {
    return Math.max(pre, cur.size().height);
  }, 0);
  nodes?.forEach((node) => {
    const { width, height } = node.size();
    if (type === "width") {
      node.setSize(maxWidth || width, height);
    } else if (type === "height") {
      node.resize(width, maxHeight || height);
    } else {
      node.resize(maxWidth || width, maxHeight || height);
    }
  });
};
